/**
 * Plugin Settings JS
 *
 * @package     wpsyncsheets-for-gravityforms
 */

/**
 * Revoke Token Button
 */
( function( $ ) {
		"use strict";
		$( document ).ready(
			function() {
				$( '#gform_google_revoke_button' ).on(
					'click',
					function( e ){
						e.preventDefault();
						changeAuthToken( '' );
					}
				);

				function changeAuthToken( token ) {
					$( 'input#authToken' ).val( token );
					$( '#gform-settings #gform-settings-save' ).trigger( 'click' );
				}
			}
		);
} )( jQuery );

/**
 * Create new Google Spreadsheet and Sheet Name
 */

( function( $ ) {
		"use strict";
		$( document ).ready(
			function() {
				$( '#clearloader' ).hide();
				$( '#cleartext' ).hide();
				$( '#gform_google_new_spreadsheet_button' ).on(
					'click',
					function( e ){
						e.preventDefault();
						var newSpreadSheetText = $( '#newspreadsheetlabel' ).val();
						var newSheetText       = $( '#sheetlabel' ).val();
						if (newSpreadSheetText === '') {
							alert( 'Please add spreadsheet name' );
							return false;
						}
						if (newSheetText === '') {
							alert( 'Please add sheet name' );
							return false;
						}
						var createNewSpreadsheet = $( '<input type=\"hidden\" name=\"createnewspreadsheet\" value=\"yes\" />' );
						$( '#gform-settings' ).append( createNewSpreadsheet );
						$( '#gform-settings #gform-settings-save' ).trigger( 'click' );
					}
				);
			}
		);
} )( jQuery );

/**
 * Sync all entries button
 */

( function( $ ) {
		"use strict";
		$( document ).ready(
			function() {
				var spreedSheets = $( "select#spreedsheets" ).val();
				$( "#gform_google_view_button" ).attr( 'href',"https://docs.google.com/spreadsheets/d/" + spreedSheets );

				$( '#gform_google_sync_button' ).on(
					'click',
					function( e ){
						e.preventDefault();
						$( '#gform_google_sync_button' ).hide();
						$( '#note' ).hide();
						$( '#syncloader' ).show();
						$( '#synctext' ).show();

						var syncAllEntries = $( '#syncallentries' ).is( ":checked" );
						var startDate      = $( 'input[name ="start_date"]' ).val();
						var endDate        = $( 'input[name ="end_date"]' ).val();
						var sheetSelect    = $( "select#sheetselect" ).val();
						var spreedSheets   = $( "select#spreedsheets" ).val();

						var formId = getUrlParameter( 'id' );
						var feedId = getUrlParameter( 'fid' );
						doAjax( feedId,formId,startDate ,endDate,syncAllEntries,sheetSelect,spreedSheets );
					}
				);
				$( '#gform_google_import_entries' ).on(
					'click',
					function( e ){
						e.preventDefault();
						$( '#gform_google_import_entries' ).hide();
						$( '#importnote' ).hide();
						$( '#importloader' ).show();
						$( '#importtext' ).show();

						var sheetSelect  = $( "select#sheetselect" ).val();
						var spreedSheets = $( "select#spreedsheets" ).val();

						var formId = getUrlParameter( 'id' );
						var feedId = getUrlParameter( 'fid' );

						if (confirm( "Are you sure? You want to import all your entries from the spreadsheet." )) {
							doImportAjax( feedId,formId,sheetSelect,spreedSheets );
						} else {
							$( '#gform_google_import_entries' ).show();
							$( '#importnote' ).show();
							$( '#importloader' ).hide();
							$( '#importtext' ).hide();
							return false;
						}
					}
				);

				$( '#gform_google_clear_button' ).on(
					'click',
					function( e ){
						e.preventDefault();

						var formId   = getUrlParameter( 'id' );
						var feedId   = getUrlParameter( 'fid' );
						var _wpnonce = $( "#wpssg_general_settings" ).val();
						var wpssg_admin_ajax_object;
						if (typeof admin_ajax_object === 'undefined') {
							wpssg_admin_ajax_object = ajaxurl;
						} else {
							wpssg_admin_ajax_object = admin_ajax_object.ajaxurl;
						}
						$.ajax(
							{
								url : wpssg_admin_ajax_object,
								type : 'post',
								data :"action=wpssg_clear_spreadsheet&form_id=" + formId + "&fid=" + feedId + "&_wpnonce=" + _wpnonce,
								beforeSend:function(){
									if (confirm( "Are you sure? You want to enable Clear Spreadsheet this is clear all your entries within the spreadsheet and you would be remained only with sheet headers." )) {
										$( '#clearloader' ).show();
									} else {
										return false;
									}
								},
								success : function( response ) {
									if (response === 'successful') {
										alert( 'Spreadsheet Cleared successfully' );
										$( '#clearloader' ).hide();
										$( '#cleartext' ).hide();
										document.getElementById( "gform_google_clear_button" ).style.display = "inline-block";
									} else {
										alert( response );
										$( '#clearloader' ).hide();
										$( '#cleartext' ).hide();
										document.getElementById( "gform_google_clear_button" ).style.display = "inline-block";
									}
								},
								error: function (s) {
									alert( 'Error' );
									$( '#clearloader' ).hide();
									$( '#cleartext' ).hide();

									document.getElementById( "gform_google_clear_button" ).style.display = "inline-block";
								}
							}
						);
					}
				);

				$( '#syncallentries' ).change(
					function() {
						if (this.checked) {
							$( '.wpssgdaterange' ).attr( 'disabled','true' );
							$( '.wpssgdaterange' ).hide();
						} else {
							$( '.wpssgdaterange' ).removeAttr( 'disabled' );
							$( '.wpssgdaterange' ).show();
						}
					}
				);

				function syncfun() {
					var syncCallButton = $( '<input type=\"hidden\" name=\"synccall\" value=\"yes\" />' );
					$( '#gform-settings' ).append( syncCallButton );
					$( '#gform-settings #gform-settings-save' ).trigger( 'click' );
				}

				var entryLimit = 500;
				var entryCount = 0;

				var obj;

				function doAjax(feedId,formId,startDate,endDate,syncAllEntries,sheetSelect,spreedSheets) {
					var _wpnonce = $( "#wpssg_general_settings" ).val();
					var wpssg_admin_ajax_object;
					if (typeof admin_ajax_object === 'undefined') {
						wpssg_admin_ajax_object = ajaxurl;
					} else {
						wpssg_admin_ajax_object = admin_ajax_object.ajaxurl;
					}
					$.ajax(
						{
							url : wpssg_admin_ajax_object,
							type : 'post',
							data :"action=wpssg_sync_count_data&start_date=" + startDate + "&end_date=" + endDate + "&syncallentries=" + syncAllEntries + "&form_id=" + formId + "&sheetselect=" + sheetSelect + "&spreedsheets=" + spreedSheets + "&fid=" + feedId + "&_wpnonce=" + _wpnonce,
							success : function( response ) {
								if ( response == 'error' ) {
									alert( 'Sorry, your nonce did not verify.' );
									$( '#syncloader' ).hide();
									$( '#synctext' ).hide();
									document.getElementById( "gform_google_sync_button" ).style.display = "inline-block";
								} else {
									obj = JSON.parse( response );

									var formId         = obj['form_id'];
									var totalEntries   = obj['totalentries'];
									var sheetName      = obj['sheetname'];
									var searchCriteria = obj['search_criteria'];

									if (totalEntries === 0) {
										alert( 'No Entries Found' );
										$( '#syncloader' ).hide();
										$( '#synctext' ).hide();
										document.getElementById( "gform_google_sync_button" ).style.display = "inline-block";
									} else {
										syncData( sheetName, totalEntries ,formId, searchCriteria );
									}
								}
							}
						}
					)
					.fail(
						function() {
							alert( 'Error' );
							$( '#syncloader' ).hide();
							$( '#synctext' ).hide();
							$( '#note' ).show();
							document.getElementById( "gform_google_sync_button" ).style.display = "inline-block";
						}
					);
				}
				function syncData( sheetName, totalEntries ,formId,searchCriteria){
					var feedId         = getUrlParameter( 'fid' );
					var searchCriteria = JSON.stringify( searchCriteria );
					if ( parseInt( totalEntries ) < 2000 ) {
						if ( parseInt( totalEntries ) > 50 ) {
							entryLimit = 200;
						} else if ( parseInt( totalEntries ) <= 50 ) {
							entryLimit = totalEntries;
						}
					} else {
						entryLimit = 500;
					}

					entryCount = entryCount + entryLimit;
					if ( totalEntries > entryLimit && entryCount < totalEntries ) {
						$( '#synctext' ).html( 'Synchronizing : ' + entryCount + ' / ' + totalEntries );
					} else {
						$( '#synctext' ).html( 'Synchronizing : ' + totalEntries + ' / ' + totalEntries );
					}
					var wpssg_admin_ajax_object;
					var sync_nonce_token;
					if (typeof admin_ajax_object === 'undefined') {
						wpssg_admin_ajax_object = ajaxurl;
					} else {
						wpssg_admin_ajax_object = admin_ajax_object.ajaxurl;
						sync_nonce_token        = admin_ajax_object.sync_nonce_token;
					}
					$.ajax(
						{
							url : wpssg_admin_ajax_object,
							type : 'post',

							data :"action=wpssg_sync_data&form_id=" + formId + "&total_entries=" + totalEntries + "&sheetname=" + sheetName + "&search_criteria=" + searchCriteria + "&entry_limit=" + entryLimit + "&fid=" + feedId + "&sync_nonce_token=" + sync_nonce_token,
							success : function( response ) {
								if (totalEntries <= entryCount ) {
									if (response === 'successful') {
										alert( 'All Entries are synchronize successfully' );
										$( '#syncloader' ).hide();
										$( '#synctext' ).hide();
										$( '#synctext' ).html( 'Synchronizing...' );
										$( '#note' ).show();
										document.getElementById( "gform_google_sync_button" ).style.display = "inline-block";
									} else {
										alert( 'Your Google Sheets API limit has been reached. Please take a look at our FAQ.' );
										$( '#syncloader' ).hide();
										$( '#synctext' ).hide();
										$( '#note' ).show();
										document.getElementById( "gform_google_sync_button" ).style.display = "inline-block";
									}
								}
							},
							complete: function(){

								var formId         = obj['form_id'];
								var totalEntries   = obj['totalentries'];
								var sheetName      = obj['sheetname'];
								var searchCriteria = obj['search_criteria'];
								if ( totalEntries > entryCount ) {
									setTimeout(
										function(){
											syncData( sheetName, totalEntries ,formId, searchCriteria );
										},
										2000
									);
								}
							}
						}
					)
					.fail(
						function() {
							alert( 'Error' );
							$( '#syncloader' ).hide();
							$( '#synctext' ).hide();
							$( '#note' ).show();
							document.getElementById( "gform_google_sync_button" ).style.display = "inline-block";
						}
					);
				}
				function doImportAjax(feedId,formId,sheetSelect,spreedSheets) {
					var _wpnonce = $( "#wpssg_import_settings" ).val();
					var wpssg_admin_ajax_object;
					if (typeof admin_ajax_object === 'undefined') {
						wpssg_admin_ajax_object = ajaxurl;
					} else {
						wpssg_admin_ajax_object = admin_ajax_object.ajaxurl;
					}
					$.ajax(
						{
							url : wpssg_admin_ajax_object,
							type : 'post',
							data :"action=wpssg_import_entries&form_id=" + formId + "&sheetselect=" + sheetSelect + "&spreedsheets=" + spreedSheets + "&fid=" + feedId + "&_wpnonce=" + _wpnonce,
							success : function( response ) {
								if ( response == 'nonce_error' ) {
									alert( 'Sorry, your nonce did not verify.' );
									$( '#importloader' ).hide();
									$( '#importtext' ).hide();
									$( '#importnote' ).show();
									document.getElementById( "gform_google_import_entries" ).style.display = "inline-block";
								} else if ( response == 'successful' ) {
									alert( 'All Entries are imported successfully' );
									$( '#importloader' ).hide();
									$( '#importtext' ).hide();
									$( '#importtext' ).html( 'Importing...' );
									$( '#importnote' ).show();
									document.getElementById( "gform_google_import_entries" ).style.display = "inline-block";
								} else if ( response == 'no_entries' ) {
									alert( 'No Entries Found' );
									$( '#importloader' ).hide();
									$( '#importtext' ).hide();
									$( '#importtext' ).html( 'Importing...' );
									$( '#importnote' ).show();
									document.getElementById( "gform_google_import_entries" ).style.display = "inline-block";
								} else {
									alert( 'Your Google Sheets API limit has been reached. Please take a look at our FAQ.' );
									$( '#importloader' ).hide();
									$( '#importtext' ).hide();
									$( '#importnote' ).show();
									document.getElementById( "gform_google_import_entries" ).style.display = "inline-block";
								}
							}
						}
					)
					.fail(
						function() {
							alert( 'Error' );
							$( '#importloader' ).hide();
							$( '#importtext' ).hide();
							$( '#importnote' ).show();
							document.getElementById( "gform_google_import_entries" ).style.display = "inline-block";
						}
					);
				}
				function getUrlParameter(sParam) {
					var sPageURL            = window.location.search.substring( 1 ),
						sURLVariables       = sPageURL.split( '&' ),
						sURLVariableslength = sURLVariables.length,
						sParameterName,
						i;
					for (i = 0; i < sURLVariableslength; i++) {
						sParameterName = sURLVariables[i].split( '=' );

						if (sParameterName[0] === sParam) {
							return sParameterName[1] === undefined ? true : decodeURIComponent( sParameterName[1] );
						}
					}
				};

				$( '#gform-settings' ).on(
					'submit',
					function(){

						if ( ! $( '#gform-settings #gform-settings-section-other-feed-settings div' ).hasClass( 'gform-settings-field__schedule_auto_sync' ) || ! $( '#gform-settings #gform-settings-section-other-feed-settings div' ).hasClass( 'gform-settings-field__schedule_auto_import' )) {
							return;
						}
						var scheduling_enable = $( 'input[name="scheduling_enable"]:checked' ).val();
						if (scheduling_enable == "1") {
							var scheduling_run_on = $( 'input[name="scheduling_run_on"]:checked' ).val();
							if ( scheduling_run_on == 'weekly' ) {
								var weekly_days = $( '#weekly_days' ).val();
								if ( weekly_days == '' ) {
									alert( 'Schedule Auto Sync:  Please select week day.' );
									$( 'html, body' ).animate(
										{
											scrollTop:$( "#weekly" ).offset().top - 160
										},
										1200
									);
									return false;
								}
							}
							if ( scheduling_run_on == 'onetime' ) {
								var scheduling_date = $( 'input[name="scheduling_date"]' ).val();
								if ( ! scheduling_date ) {
									$( 'html, body' ).animate(
										{
											scrollTop:$( "#onetime" ).offset().top - 160
										},
										1200
									);
									alert( 'Schedule Auto Sync:  Please select date.' );
									return false;
								}
								var scheduling_time = $( 'input[name="scheduling_time"]' ).val();
								if ( ! scheduling_time ) {
									$( 'html, body' ).animate(
										{
											scrollTop:$( "#onetime" ).offset().top - 160
										},
										1200
									);
									alert( 'Schedule Auto Sync:  Please select time.' );
									return false;
								}
							}
						}

						var import_scheduling_enable = $( 'input[name="import_scheduling_enable"]:checked' ).val();
						if (import_scheduling_enable == "1") {
							var import_scheduling_run_on = $( 'input[name="import_scheduling_run_on"]:checked' ).val();
							if ( import_scheduling_run_on == 'weekly' ) {
								var weekly_days = $( '#import_weekly_days' ).val();
								if ( weekly_days == '' ) {
									alert( 'Schedule Auto Import:  Please select week day.' );
									$( 'html, body' ).animate(
										{
											scrollTop:$( "#import_weekly" ).offset().top - 160
										},
										1200
									);
									return false;
								}
							}
							if ( import_scheduling_run_on == 'onetime' ) {
								var import_scheduling_date = $( 'input[name="import_scheduling_date"]' ).val();
								if ( ! import_scheduling_date ) {
									$( 'html, body' ).animate(
										{
											scrollTop:$( "#import_onetime" ).offset().top - 160
										},
										1200
									);
									alert( 'Schedule Auto Import:  Please select date.' );
									return false;
								}
								var import_scheduling_time = $( 'input[name="import_scheduling_time"]' ).val();
								if ( ! import_scheduling_time ) {
									$( 'html, body' ).animate(
										{
											scrollTop:$( "#import_onetime" ).offset().top - 160
										},
										1200
									);
									alert( 'Schedule Auto Import:  Please select time.' );
									return false;
								}
							}
						}
					}
				);

				if ( $( '#gform-settings #gform-settings-section-other-feed-settings div' ).hasClass( 'gform-settings-field__schedule_auto_sync' ) || $( '#gform-settings #gform-settings-section-other-feed-settings div' ).hasClass( 'gform-settings-field__schedule_auto_import' )) {
					$( '#weekly li' ).click(
						function () {
							if ($( this ).hasClass( 'selected' )) {
								$( this ).removeClass( 'selected' );
							} else {
								$( this ).addClass( 'selected' );
							}

							$( '#weekly_days' ).val( '' );

							$( '#weekly li.selected' ).each(
								function () {
									var val = $( this ).data( 'day' );
									$( '#weekly_days' ).val( $( '#weekly_days' ).val() + val + ',' );
								}
							);

							$( '#weekly_days' ).val( $( '#weekly_days' ).val().slice( 0, -1 ) );

						}
					);
					$( 'input[name="scheduling_run_on"]' ).change(
						function () {
							var val = $( 'input[name="scheduling_run_on"]:checked' ).val();
							showinterval( val );
						}
					);
					$( 'input[name="scheduling_enable"]' ).change(
						function () {
							var val = $( 'input[name="scheduling_enable"]:checked' ).val();
							showschedule( val );
						}
					);
					var val = $( 'input[name="scheduling_enable"]:checked' ).val();
					showschedule( val );

					$( '#import_weekly li' ).click(
						function () {
							if ($( this ).hasClass( 'selected' )) {
								$( this ).removeClass( 'selected' );
							} else {
								$( this ).addClass( 'selected' );
							}

							$( '#import_weekly_days' ).val( '' );

							$( '#import_weekly li.selected' ).each(
								function () {
									var val = $( this ).data( 'day' );
									$( '#import_weekly_days' ).val( $( '#import_weekly_days' ).val() + val + ',' );
								}
							);

							$( '#import_weekly_days' ).val( $( '#import_weekly_days' ).val().slice( 0, -1 ) );

						}
					);
					$( 'input[name="import_scheduling_run_on"]' ).change(
						function () {
							var val = $( 'input[name="import_scheduling_run_on"]:checked' ).val();
							showimport_interval( val );
						}
					);
					$( 'input[name="import_scheduling_enable"]' ).change(
						function () {
							var val = $( 'input[name="import_scheduling_enable"]:checked' ).val();
							showimport_schedule( val );
						}
					);
					var val = $( 'input[name="import_scheduling_enable"]:checked' ).val();
					showimport_schedule( val );
				}
			}
		);
} )( jQuery );

/**
 * Set Default Google Spreadsheet Headers
 */

( function( $ ) {
		"use strict";
		$( document ).ready(
			function() {
				$( '#gform_google_header_button' ).on(
					'click',
					function( e ){
						e.preventDefault();
						changeAuthToken();
					}
				);
				function changeAuthToken() {
					var headerSet = $( '<input type=\"hidden\" name=\"headerset\" value=\"yes\" />' );
					$( '#gform-settings' ).append( headerSet );
					$( '#gform-settings #gform-settings-save' ).trigger( 'click' );
				}
			}
		);
} )( jQuery );

function showschedule( val ){
	var intervalval = jQuery( 'input[name="scheduling_run_on"]:checked' ).val();
	showinterval( intervalval );
	if ( val == "0" ) {
		jQuery( '#automatic-scheduling' ).slideUp();
	} else if (val == "1") {
		jQuery( '#automatic-scheduling' ).slideDown();
	}
}
function showinterval( val ){
	if ( val == "weekly" ) {
		jQuery( '#weekly' ).slideDown( 200 );
		jQuery( '#scheduling_date' ).slideUp( 175 );
		jQuery( '#schedule_recurrence' ).slideUp( 175 );
	} else if ( val == "onetime" ) {
		jQuery( '#scheduling_date' ).slideDown( 200 );
		jQuery( '#weekly' ).slideUp( 175 );
		jQuery( '#schedule_recurrence' ).slideUp( 175 );
	} else if ( val == "recurrence" ) {
		jQuery( '#schedule_recurrence' ).slideDown( 200 );
		jQuery( '#weekly' ).slideUp( 175 );
		jQuery( '#scheduling_date' ).slideUp( 175 );
	}
}
function showimport_schedule( val ){
	var intervalval = jQuery( 'input[name="import_scheduling_run_on"]:checked' ).val();
	showimport_interval( intervalval );
	if ( val == "0" ) {
		jQuery( '#import-automatic-scheduling' ).slideUp();
	} else if (val == "1") {
		jQuery( '#import-automatic-scheduling' ).slideDown();
	}
}
function showimport_interval( val ){
	if ( val == "weekly" ) {
		jQuery( '#import_weekly' ).slideDown( 200 );
		jQuery( '#import_scheduling_date' ).slideUp( 175 );
		jQuery( '#import_schedule_recurrence' ).slideUp( 175 );
	} else if ( val == "onetime" ) {
		jQuery( '#import_scheduling_date' ).slideDown( 200 );
		jQuery( '#import_weekly' ).slideUp( 175 );
		jQuery( '#import_schedule_recurrence' ).slideUp( 175 );
	} else if ( val == "recurrence" ) {
		jQuery( '#import_schedule_recurrence' ).slideDown( 200 );
		jQuery( '#import_weekly' ).slideUp( 175 );
		jQuery( '#import_scheduling_date' ).slideUp( 175 );
	}
}
