<?php
/**
 * Activate License
 *
 * @package wpsyncsheets-for-gravityforms
 */

// Direct access security.
if ( ! defined( 'WPSSG_PLUGIN_SECURITY' ) ) {
	wp_die();
}
use WPSyncSheets_Gravity_Forms\WPSSG_Google_API_Functions;
/**
 * Check Plugin License.
 */
final class WPSSG_Licence {

	/**
	 * Instance of class.
	 *
	 * @var $instance Instance variable of class.
	 */
	protected static $instance = null;
	/**
	 * Instance of WPSSG_Google_API_Functions class.
	 *
	 * @var $instance_api Instance variable of WPSSG_Google_API_Functions class.
	 */
	private static $instance_api = null;
	/**
	 * Get an instance of this class.
	 *
	 * @return instance
	 */
	public static function instance() {
		if ( is_null( self::$instance ) ) {
			self::$instance = new self();
		}
		return self::$instance;
	}
	/**
	 * Get an instance of WPSSG_Google_API_Functions class.
	 *
	 * @return WPSSG_Google_API_Functions class instance
	 */
	public static function wpssg_google_api() {
		if ( null === self::$instance_api ) {
			self::$instance_api = new WPSSG_Google_API_Functions();
		}
		return self::$instance_api;
	}
	/**
	 * Primary class constructor.
	 *
	 * @since 1.0.0
	 */
	public function __construct() {
		$this->wpssg_google_api();
		add_action( 'init', array( $this, 'wpssg_plugin_updater' ) );
	}
	/**
	 * Initialization
	 */
	public function init() {
	}
	/**
	 * Initialize the updater. Hooked into `init` to work with the
	 * wp_version_check cron job, which allows auto-updates.
	 */
	public function wpssg_plugin_updater() {

		// To support auto-updates, this needs to run during the wp_version_check cron job for privileged users.
		$doing_cron = defined( 'DOING_CRON' ) && DOING_CRON;
		if ( ! current_user_can( 'manage_options' ) && ! $doing_cron ) {
			return;
		}

		// retrieve our license key from the DB.
		$license_key = trim( self::$instance_api->wpssg_option( 'wpssg_license_key' ) );
		// setup the updater.
		$edd_updater = new WPSSG_Plugin_Update(
			WPSSG_STORE_URL,
			WPSSG_BASE_FILE,
			array(
				'version' => WPSSG_VERSION,
				'license' => $license_key,
				'item_id' => WPSSG_PLUGIN_ITEM_ID,
				'author'  => 'Creative Werk Designs',
				'beta'    => false,
			)
		);
	}
}
